SELECT 100/pymysql - Criterion.rs

## SELECT 100/pymysql

#### Additional Statistics:

| Lower bound | Estimate | Upper bound
--- | --- | --- | ---
R² | 0.0064837 | 0.0067203 | 0.0064645
Mean | 15.110 ms | 15.277 ms | 15.452 ms
Std. Dev. | 737.08 µs | 876.48 µs | 1.0082 ms
Median | 14.807 ms | 14.986 ms | 15.577 ms
MAD | 649.77 µs | 917.50 µs | 1.1065 ms

#### Additional Plots:

- Typical
- Mean
- Std. Dev.
- Median
- MAD

#### Understanding this report:

The plot on the left displays the average time per iteration for this benchmark. The shaded region shows the estimated probability of an iteration taking a certain amount of time, while the line shows the mean. Click on the plot for a larger view showing the outliers.

The plot on the right shows the average time per iteration for the samples. Each point represents one sample.

See the documentation for more details on the additional statistics.